@@ -1,28 +1,26 @@
 #!/usr/bin/env python3
 
-# uncomment to print debug info during instrumentation
-# import assignhooks.transformer
-# assignhooks.transformer.debug = True
-
 import assignhooks
 
-assignhooks.instrument.start()
+# uncomment to print debug info during instrumentation
+# assignhooks.instrument.debug = True
+# assignhooks.patch.debug = True
+# assignhooks.transformer.debug = True
 
-# following import(s) will be instrumented
+assignhooks.instrument.start()    # following imports will be instrumentated
 import testmod
+assignhooks.instrument.stop()     # next imports won't be instrumented
 
 print('======= WITH instrumentation ======')
 testmod.fun()
 
 
-# all imports above are instrumented until this call is executed
-assignhooks.instrument.stop()
+# now importing wihout instrumentation
+import testmod2
 
-# following imoprt(s) will NOT be instrumented
 # it is the same module actually, just with different name
 # so that python attempts to import it (else it will ignore it)
 # and differnt assertions for expected results when not instrumented
-import testmod2
 
 print('======= WITHOUT instrumentation ======')
 testmod2.fun()
